@@ -36,24 +36,24 @@ public:
         PreferCloud
     };
 
-    explicit ConflictDialog( QWidget *parent = nullptr );
-    void setMergeItem( MergeItem *item );
+    explicit ConflictDialog(QWidget *parent = nullptr);
+    void setMergeItem(MergeItem *item);
 
 public Q_SLOTS:
     void open() override;
     void stopAutoResolve();
 
 Q_SIGNALS:
-    void resolveConflict( MergeItem *mergeItem );
+    void resolveConflict(MergeItem *mergeItem);
 
 private Q_SLOTS:
-    void resolveConflict( QAbstractButton *button );
+    void resolveConflict(QAbstractButton *button);
 
 private:
     void prepareLayout();
 
-    MergeItem *m_mergeItem;
-    QDialogButtonBox *m_box;
+    MergeItem *m_mergeItem = nullptr;
+    QDialogButtonBox *m_box = nullptr;
     ConflictDialog::ResolveAction m_resolveAction;
 };
 
