@@ -6,8 +6,8 @@
 #ifndef MARBLE_ROUTE_H
 #define MARBLE_ROUTE_H
 
-#include "RouteSegment.h"
 #include "GeoDataLatLonBox.h"
+#include "RouteSegment.h"
 
 namespace Marble
 {
@@ -17,31 +17,31 @@ class MARBLE_EXPORT Route
 public:
     Route();
 
-    void addRouteSegment( const RouteSegment &segment );
+    void addRouteSegment(const RouteSegment &segment);
 
     GeoDataLatLonBox bounds() const;
 
     qreal distance() const;
 
-    const RouteSegment & at( int index ) const;
+    const RouteSegment &at(int index) const;
 
     int indexOf(const RouteSegment &segment) const;
 
     int size() const;
 
-    const GeoDataLineString & path() const;
+    const GeoDataLineString &path() const;
 
     int travelTime() const;
 
-    const GeoDataLineString & turnPoints() const;
+    const GeoDataLineString &turnPoints() const;
 
-    const GeoDataLineString & waypoints() const;
+    const GeoDataLineString &waypoints() const;
 
-    void setPosition( const GeoDataCoordinates &position );
+    void setPosition(const GeoDataCoordinates &position);
 
     GeoDataCoordinates position() const;
 
-    const RouteSegment & currentSegment() const;
+    const RouteSegment &currentSegment() const;
 
     GeoDataCoordinates currentWaypoint() const;
 
@@ -54,7 +54,7 @@ private:
 
     qreal m_distance;
 
-    QVector<RouteSegment> m_segments;
+    QList<RouteSegment> m_segments;
 
     GeoDataLineString m_path;
 
